@@ -1,11 +1,12 @@
-from django.shortcuts import render_to_response, render
+from django.shortcuts import render
 from django.http import HttpResponse
 from django.template import RequestContext
 
 # Create your views here.
 def index(request):
 
-    return render_to_response(
+    return render(
+            request,
             'inapp_survey/index.html',
-            context_instance=RequestContext(request))
+            context={})
     # return HttpResponse("Hello, world. You're at the in app index.")
